==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframehistogramareaextra.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Helper frames that go togeter with iggWidgetHistogramArea
//

#ifndef IGGFRAMEHISTOGRAMAREAEXTRA_H
#define IGGFRAMEHISTOGRAMAREAEXTRA_H


#include "iggframe.h"


class iggWidgetHistogramArea;
class iggWidgetNumberDisplay;


class iggFrameHistogramAreaExtra : public iggFrame
{

public:

	iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent);

protected:

	virtual bool UpdateWidgetBody();

	iggWidgetHistogramArea *mArea;
	iggWidgetNumberDisplay *mDisplayMin, *mDisplayMax;
};


#endif  // IGGFRAMEHISTOGRAMAREAEXTRA_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggframehistogramareaextra.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Helper frames that go togeter with iggWidgetHistogramArea
//

#ifndef IGGFRAMEHISTOGRAMAREAEXTRA_H
#define IGGFRAMEHISTOGRAMAREAEXTRA_H


#include "iggframe.h"


class iggWidgetHistogramArea;
class iggWidgetNumberDisplay;


class iggFrameHistogramAreaExtra : public iggFrame
{

public:

	iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent);

protected:

	virtual void UpdateWidgetBody();

	iggWidgetHistogramArea *mArea;
	iggWidgetNumberDisplay *mDisplayMin, *mDisplayMax;
};


#endif  // IGGFRAMEHISTOGRAMAREAEXTRA_H
